@@ -12,7 +12,7 @@ from dataquality.schemas import RequestType, Route
 from dataquality.schemas.job import JobName
 from dataquality.schemas.task_type import TaskType
 from dataquality.utils.dq_logger import DQ_LOG_FILE_HOME, upload_dq_log_file
-from dataquality.utils.helpers import check_noop
+from dataquality.utils.helpers import check_noop, open_console_url
 from dataquality.utils.thread_pool import ThreadPoolManager
 from dataquality.utils.version import _version_check
 
@@ -22,8 +22,10 @@ a = Analytics(ApiClient, config)  # type: ignore
 
 @check_noop
 def finish(
-    last_epoch: Optional[int] = None, wait: bool = True
-) -> Optional[Dict[str, Any]]:
+    last_epoch: Optional[int] = None,
+    wait: bool = True,
+    create_data_embs: bool = False,
+) -> str:
     """
     Finishes the current run and invokes a job
 
@@ -32,6 +34,10 @@ def finish(
     :param wait: If true, after uploading the data, this will wait for the
         run to be processed by the Galileo server. If false, you can manually wait
         for the run by calling `dq.wait_for_run()` Default True
+    :param create_data_embs: If True, an off-the-shelf transformer will run on the raw
+        text input to generate data-level embeddings. These will be available in the
+        `data view` tab of the Galileo console. You can also access these embeddings
+        via dq.metrics.get_data_embeddings()
     """
     a.log_function("dq/finish")
     ThreadPoolManager.wait_for_threads()
@@ -46,7 +52,7 @@ def finish(
     if data_logger.non_inference_logged():
         _reset_run(config.current_project_id, config.current_run_id, config.task_type)
 
-    data_logger.upload(last_epoch)
+    data_logger.upload(last_epoch, create_data_embs=create_data_embs)
     upload_dq_log_file()
 
     body = dict(
@@ -55,6 +61,7 @@ def finish(
         labels=data_logger.logger_config.labels,
         task_type=config.task_type.value,
         tasks=data_logger.logger_config.tasks,
+        ner_labels=data_logger.logger_config.ner_labels,
     )
     if data_logger.logger_config.inference_logged:
         body.update(
@@ -74,6 +81,7 @@ def finish(
             "Don't close laptop or terminate shell."
         )
         wait_for_run()
+        open_console_url(res["link"])
         build_run_report(
             data_logger.logger_config.conditions,
             data_logger.logger_config.report_emails,
@@ -83,10 +91,11 @@ def finish(
         )
     elif wait:
         wait_for_run()
+        open_console_url(res["link"])
 
     # Reset the environment
     data_logger._cleanup()
-    return res
+    return res.get("link") or ""
 
 
 @check_noop
