@@ -1,4 +1,5 @@
 from dataquality.loggers.model_logger import (
+    image_classification,
     text_classification,
     text_multi_label,
     text_ner,
@@ -6,6 +7,7 @@ from dataquality.loggers.model_logger import (
 from dataquality.loggers.model_logger.base_model_logger import BaseGalileoModelLogger
 
 __all__ = [
+    "image_classification",
     "text_classification",
     "text_multi_label",
     "text_ner",
